@@ -1,7 +1,6 @@
 import click
 
 from cli.utils import Spotify
-from cli.utils.exceptions import SpotifyAPIError
 
 
 @click.command(options_metavar='[<options>]')
@@ -15,17 +14,11 @@ from cli.utils.exceptions import SpotifyAPIError
 )
 def pause(verbose=0, quiet=False):
     """Pause playback."""
-    try:
-        Spotify.request('me/player/pause', method='PUT')
-    except SpotifyAPIError as e:
-        if e.status == 403:
-            pass
-        else:
-            raise e
+    Spotify.request('me/player/pause', method='PUT', ignore_errs=[403])
 
     if not quiet:
         from cli.commands.status import status
-        status.callback(verbose=verbose, override={'is_playing': False})
+        status.callback(verbose=verbose, _override={'is_playing': False})
 
 
     return
