@@ -10,6 +10,9 @@ from cli.commands.next import _next
 from cli.commands.previous import previous
 from cli.commands.devices import devices
 from cli.commands.volume import volume
+from cli.commands.shuffle import shuffle
+from cli.commands.repeat import repeat
+from cli.commands.save import save
 
 
 # CLI group
@@ -31,3 +34,6 @@ cli.add_command(_next)
 cli.add_command(previous)
 cli.add_command(devices)
 cli.add_command(volume)
+cli.add_command(shuffle)
+cli.add_command(repeat)
+cli.add_command(save)
